import os
import threading
class Scan:
    def __init__(self,range = '192.168.1'):
        self.range = range
        self.ip_list = []
        if os.name == "nt":
            def scan_device(ip):
                address = ip
                response = os.popen("ping -n 1 " + address).read()

                if "ttl" in response.lower():
                    self.ip_list.append(address)
        else:
            def scan_device(ip):
                address = ip
                response = os.system("ping -c 1 " + address)

                if "ttl" in response.lower():
                    self.ip_list.append(address)
        self.ping = scan_device
    def run(self):
        # Create a list of threads
        threads = []
        # Scan
        for i in range(1, 255):
            ip = self.range + "." + str(i)
            t = threading.Thread(target=self.ping, args=(ip,))
            threads.append(t)
            t.start()
        # Wait for all threads to complete
        for t in threads:
            t.join()
        return self.ip_list
if __name__ == '__main__':
    a=Scan("192.168.31")
    for i in a.run():
        print(i)
    print("扫描完成")


import re
import meo
import requests
import threading
import sys
import os
from tqdm import tqdm
script_path = os.path.split(os.path.realpath(__file__))[0]
sys.path.append(os.path.join(script_path, "../../"))
import path_dict

#仿站
from .imitate import Imitate

HOST_PATTERN = r".+://(.+)"
headers = {
    "User-Agent": meo.net.UserAgent.FIREFOX
}


def getsrc(url, output=None, headers=headers):
    host_match = re.match(HOST_PATTERN, url)
    host = host_match.group(1)
    try:
        response = requests.get(url, headers)
        response.encoding = "utf-8"
        fname = host.replace("/", "_")
        if output is None:
            output = f"./output/{fname}"
        meo.to_file(output, response.text)
        return output
    except:
        return None


def post(url, data):
    try:
        response = requests.post(url, data=data)
        response.encoding = "utf-8"
        return response.text
    except:
        return None


def get(url, data):
    try:
        response = requests.get(url, params=data)
        response.encoding = "utf-8"
        return response.text
    except:
        return None

# 提交表单
def upform(url,method = 'get',formdata = None):
    if method in ["1", "post"]:
        return post(url, formdata)
    elif method in ["2", "get"]:
        return get(url, formdata)
    else:
        return None

# 后台文件扫描
def findadmin(url,kind = 1):
    up_list = []
    def scan(path):
        path = path.strip()
        try:
            txturl = url + path
            r = requests.get(txturl, headers)
            if r.status_code == requests.codes.ok:
                up_list.append(txturl)
        except:
            return 0

    if kind in ["0", "全部"]:
        kind = 1
    elif kind in ["1", "ASP", "asp"]:
        kind = "ASP.txt"
    elif kind in ["2", "ASPX", "aspx"]:
        kind = "ASPX.txt"
    elif kind in ["3", "DIR", "dir"]:
        kind = "DID.txt"
    elif kind in ["4", "JSP", "jsp"]:
        kind = "JSP.txt"
    elif kind in ["5", "MDB", "mdb"]:
        kind = "MDB.txt"
    elif kind in ["6", "PHP", "php"]:
        kind = "PHP.txt"
    else:
        kind = 1
    # Create a list of threads
    threads = []
    if kind == 1:
        kind = ["ASP.txt", "ASPX.txt", "DIR.txt",
                "JSP.txt", "MDB.txt", "PHP.txt"]
        for ikind in kind:
            txtlist = path_dict.get_file(ikind)
            for i in tqdm(txtlist):
                t = threading.Thread(target=scan, args=(i,))
                threads.append(t)
                t.start()
    else:
        txtlist = path_dict.get_file(kind)
        for i in tqdm(txtlist):
            # print("\r进度("+str(s+f)+"/"+str(num)+")",end="")
            t = threading.Thread(target=scan, args=(i,))
            threads.append(t)
            t.start()
    for t in threads:
        t.join()
    return up_list
if __name__ == "__main__":
    getsrc(
        "https://miaobuao.github.io/"
    )
    ...



import zipfile
import time
import asyncio
from tqdm import tqdm
from itertools import permutations
import multiprocessing
import itertools

#PWD_SEED = b"1234567890qwertyuiopasdfghjklzxcvbnmQWERTYUIOPASDFGHJKLZXCVBNM!@#$%^&*()_+-=[{}]\|;:,<.>/?'\" "
PWD_SEED = ""
def try_open_zip(file, pwd):
    assert isinstance(file, zipfile.ZipFile)
    try:
        if isinstance(pwd, str):
            pwd = pwd.encode('utf8')
        mem = file.namelist()[0]
        with file.open(mem, pwd=pwd) as f:
            if f.seek(1):
                return True
    except:
        return False
    
def guess_number_pwd(file):
    start_time = time.time()
    zfile = zipfile.ZipFile(file)
    print("开始爆破(纯数字)")
    for number in tqdm(range(999999999)):
        pwd = str(number).encode("utf8")
        if try_open_zip(zfile, pwd):
            print("破解成功，压缩包密码为 %s ,用时 %s s"%(str(pwd), int(time.time()-start_time)))
            return pwd
            
def key_permution(seed, size):
    for k in permutations(seed, size):
        yield bytes(k)

def key_generator(start=None, end=None, seed=PWD_SEED):
    n_size = 0 if start is None else int(start)
    if end is None:
        while True:
            n_size += 1
            for k in key_permution(PWD_SEED, n_size):
                yield k, n_size
    else:
        end = int(end)
        while True:
            n_size += 1
            if n_size <= end:
                for k in key_permution(PWD_SEED, n_size):
                    yield k, n_size

async def guess_async(path, min_length=None, max_length=None):
    zfile = zipfile.ZipFile(path)

    async def block(pwd):
        if try_open_zip(zfile, pwd):
            return pwd
        return False
    
    with tqdm(key_generator(min_length, max_length)) as bar:
        async for pwd, n_size in bar:
            if await block(pwd):
                return pwd
    return None

def guess_pwd_normal(path, min_length=None, max_length=None):
    start_time = time.time()
    loop = asyncio.get_event_loop()
    future = asyncio.ensure_future(guess_async(path, min_length, max_length))
    loop.run_until_complete(future)
    pwd = future.result()
    if pwd:
        print("破解成功，压缩包密码为 %s ,用时 %s s"%(pwd.decode("utf8"), time.time() - start_time))
    else:
        print("破解失败！")
    return pwd

def __block(file, pwds):
    zfile = zipfile.ZipFile(file)
    for pwd, _ in pwds:
        if try_open_zip(zfile, pwd):
            return pwd
    return False


def guess_in_multiprocess(path, min_length=None, max_length=None, n_processes=8, slice_size=500):
    pool = multiprocessing.Pool(n_processes)
    it = key_generator(min_length, max_length)
    manager = multiprocessing.Manager()
    info = manager.dict()
    info['key'] = None
    def cb(re):
        if re:
            info['key'] = re
            pool.terminate()
    while True:
        for _ in range(n_processes):
            try:
                pwds = itertools.islice(it, 0, slice_size)
                pool.apply_async(__block, (path, list(pwds)), callback=cb)
            except Exception as e:
                if e.args[0] == 'Pool not running':
                    return info['key']
                else:
                    raise e

class ZipPasswordGuesser:

    def __init__(self, path, seed=PWD_SEED) -> None:
        self.seed = seed
        self.path = path

    def guess_number(self):
        return guess_number_pwd(self.path)
    
    async def guess_async(self, min_length=None, max_length=None):
        return await guess_async(self.path, min_length, max_length)
    
    def guess_normal(self, min_length=None, max_length=None):
        return guess_pwd_normal(self.path, min_length, max_length)
    
    def guess_mp(self, min_length=None, max_length=None, n_processes=8, slice_size=500):
        return guess_in_multiprocess(self.path, min_length, max_length, n_processes, slice_size)

def zipkey(path,mode):
    path = remove_quotes(path)
    global PWD_SEED
    if mode in ["number",0]:
        PWD_SEED = b"1234567890"
    elif mode in ["letter + number",1]:
        PWD_SEED = b"1234567890qwertyuiopasdfghjklzxcvbnmQWERTYUIOPASDFGHJKLZXCVBNM"
    elif mode in ["letter + number + symbol",2]:
        PWD_SEED = b"1234567890qwertyuiopasdfghjklzxcvbnmQWERTYUIOPASDFGHJKLZXCVBNM!@#$%^&*()_+-=[{}]\|;:,<.>/?'\" "
    st = time.time()
    zp = ZipPasswordGuesser(path)
    k = zp.guess_mp(n_processes=16, slice_size=1000)
    #k = zp.guess_normal()
    ed = time.time()
    return k.decode('utf8'),int((ed - st)*10)/10

# 检测并去除引号
def remove_quotes(string):
    if len(string) >= 2 and string[0] == string[-1] and (string[0] == '"' or string[0] == "'"):
        return string[1:-1]
    return string



if __name__ == "__main__":
    # zipkey_plus(r"C:\Users\yourm\Desktop\1\flag.zip")
    # guess_pwd("./test/flag.zip")
    # st = time.time()
    # zp = ZipPasswordGuesser("./test/flag.zip")
    # k = zp.guess_mp(n_processes=16, slice_size=1000)
    # k = zp.guess_normal()
    # print(k)
    # ed = time.time()
    # print(ed - st)
    password,time = zipkey(r"C:\Users\yourm\Desktop\1\flag.zip",1)
    ...



# -*- coding: utf-8 -*-
# by yourmoln
import sys
import os
script_path = os.path.split(os.path.realpath(__file__))[0]
sys.path.append(script_path)
import core
import random
import pickle
def yiyan():
    with open(os.path.join(script_path, "./database/YiYan.dat"), "rb") as f:
        YiYans = pickle.loads(f.read())
    meo.screen.blue_font('一言:'+YiYans[str(random.randint(1, len(YiYans)))])
def start():
    print(core.__docs__)
    yiyan()
requirements_path = os.path.join(script_path, "../requirements.txt")
for _ in range(3):
    try:
        import requests
        import meo
        import bs4
        import pywifi
        import tqdm
        import asyncio
        break
    except:
        source_list = [
            "https://pypi.douban.com/simple",
            "https://pypi.org/simple"
        ]
        print("有缺失的包，请选择一种下载方式: ")
        print("\n".join([
            f"[{i + 1}] {source}"
            for i, source in enumerate(source_list)
        ]))
        idx = int(input("请输入序号(推荐使用1): ")) - 1
        #requirements_path = os.path.join(script_path, "../requirements.txt")
        os.system(
            f"python -m pip install -r {requirements_path} -i {source_list[idx]}"
        )
        print("\a安装完成，开始运行")




import core.network as network
import core.web as web
import core.zip as zip
import core.encode as encode
import core.LAN as LAN

def run():
    import sys
    import os
    import threading
    script_path = os.path.split(os.path.realpath(__file__))[0]
    sys.path.append(script_path)
    start()
    mainmode = input("请选择模式:\n[0]本机信息\n[1]web\n[2]network\n[3]LAN\n[4]密文处理\n[5]压缩包破解\n")
    if mainmode in ["0", "本机信息"]:
        print("获取信息中...")
        a = network.Hostinfo()
        result = a.all()
        for key,value in result.items():
            print("="*20)
            print(key)
            for k,v in value.items():
                print(k,v)
    elif mainmode in ["1", "web"]:
        ssl = input("是否为https://\n[1]是\n[2]否\n")
        if ssl in ["是", "1"]:
            ssl = "https://"
        elif ssl in ["否", "2"]:
            ssl = "http://"
        else:
            print("未选择，默认为是")
            ssl = "https://"
        name = input("请输入链接:"+ssl)
        url = ssl+name
        mode = input("请选择模式:\n[1]下载源码\n[2]获取ip\n[3]提交表单\n[4]后台扫描\n[5]洪水攻击\n")
        # 判断模式
        if mode in ["1", "获取源码"]:
            src = web.getsrc(url)
            print(f"已写入文件{src}") if src != None else print("获取失败")
        if mode in ["2", "获取ip"]:
            print(f"ip:{network.getip(name)}")
        if mode in ["3", "提交表单"]:
            formname = formvalue = []
            formdata = {}
            method = input("请选择方法:\n[1]post\n[2]get\n不作选择默认为post\n")
            n = int(input("请选择提交数量:"))
            for i in range(n):
                formname += [input("请输入第"+str(i+1)+"个变量名:")]
                formvalue += [input("请输入第"+str(i+1)+"个变量值:")]
            for i in range(n):
                formdata[formname[i]] = formvalue[i]
            result = web.upform(url,method = method,formdata = formdata)
            print(result) if result != None else print("提交失败")
        if mode in ["4", "后台扫描"]:
            kind = input("请选择后台语言类型\n[0]全部\n[1]ASP\n[2]ASPX\n[3]DIR\n[4]JSP\n[5]MDB\n[6]PHP\n默认为全部\n")
            print("扫描中，将在扫描结束后显示结果")
            result = web.findadmin(url, kind = kind)
            for i in result:
                print(i)
        if mode in ["5", "洪水攻击"]:
            try:
                speed = int(input("请输入攻击速度(小心卡死自己):"))
                speed = speed if speed > 0 else 10
            except:
                print("设置错误，默认为10")
                speed = 10
            a = network.Attack(url,speed)
            a.run()
            while a.start:
                print("\r已发送{}个包，失效{}个包".format(
                a.collector['success'] + a.collector['err'],
                a.collector['err']
            ), end="")
    elif mainmode in ["2", "network"]:
        target_ip = input("请输入目标ip:")
        mode = input("请选择模式:\n[1]泛洪攻击\n[2]洪攻击\n[3]ping\n")

        if mode in ["1", "泛洪攻击"]:
            print("\033[31m注意！此功能极有可能耗尽你的宽带\033[0m")#红色字体
            port = int(input("请输入起始端口:"))
            d = network.Ddos(target_ip, port = port)
            d.all()
            while d.start:
                print ("\r已发送 %s 个包到 %s 通过端口:%s"%(d.data['sent'],d.ip,d.data['port']),end="")
        if mode in ["2", "洪攻击"]:
            print("\033[31m注意！此功能极有可能耗尽你的宽带\033[0m")#红色字体
            port = int(input("请输入目标端口:"))
            d = network.Ddos(target_ip, port = port)
            d.one()
            while d.start:
                print ("\r已发送 %s 个包到 %s 通过端口:%s"%(d.data['sent'],d.ip,d.port),end="")
        if mode in ["3", "ping"]:
            print("pinging...")
            print(network.ping(target_ip))
    elif mainmode in ["3", "LAN"]:
        mode = input("请选择模式:\n[1]设备扫描\n")

        if mode in ["1", "设备扫描"]:
            range = input("请输入扫描范围\n例:192.168.1\n")
            print("扫描中...")
            scan = LAN.Scan(range = range)
            for i in scan.run():
                print(i)
            print("扫描完成")
    elif mainmode in ["4", "密文处理"]:
        codetext = input("请输入文本:")
        mode = input("请选择模式:\n[1]一键解密\n[2]栅栏解密\n")
        if mode in ["1", "一键解密"]:
            dc = encode.todecode(codetext)
            result = dc.autodecode()
            print("解密结果如下")
            for key, value in result.items():
                if value is not None:
                    print(key, value)
        if mode in ["2", "栅栏解密"]:
            textlengh = int(input("每组字数:"))
            print(encode.fence.decrypt(codetext, textlengh))

    elif mainmode in ["5", "压缩包破解"]:
        zip_path = input("请输入压缩包路径:")
        mode = input("请选择破解模式:\n[1]纯数字\n[2]数字字母混合\n[3]数字字母符号混合\n")
        if mode in ["1", "纯数字"]:
            password,time = zip.zipkey(zip_path,0)
        if mode in ["2", "数字字母混合"]:
            password,time = zip.zipkey(zip_path,1)
        if mode in ["3", "数字字母符号混合"]:
            password,time = zip.zipkey(zip_path,2)
        print(f"密码为{password},总共耗时{time}秒")
    if os.name == "nt":
        input("按回车键结束程序")


import sys
import os

__dir__ = os.path.split(os.path.realpath(__file__))[0]

def get_file_path(name):
    return os.path.join(__dir__, name)

def get_file(name, encoding='gbk'):
    fpath = get_file_path(name)
    with open(fpath, 'r', encoding=encoding) as f:
        return f.readlines()



# https://github.com/miaobuao/ImitateWebSite
import sys
import threading
import re
import os
import requests as r
from bs4 import BeautifulSoup as bs
from urllib.parse import urlparse


class Download(threading.Thread):
    def isHttps(self, https_url):
        try:
            if r.get(https_url).status_code == 200:
                return True
        except:
            return False

    def __init__(self):
        super(Download, self).__init__()
        self.path = ''
        self.url = ''
        self.r = ''

    def fixUrl(self, url):
        info = urlparse(url)
        path = ''
        oldpath = info[2]
        for i in oldpath.split("/"):
            if i:
                path += ('/'+i)
        if not info[0]:
            https = "https://"+info[1]+path
            if self.isHttps(https):
                return https
            else:
                return "http://"+info[1]+path
        else:
            return info[0]+"://"+info[1]+path

    def add(self, url, path):
        self.path = path
        self.url = self.fixUrl(url)
        info = os.path.split(self.path)
        if not os.path.isdir(info[0]):
            os.makedirs(info[0])
        self.r = r.get(self.url, stream=True)
        # print(self.url+" :: "+self.path)

    def run(self):
        with open(self.path, 'wb') as f:
            for chunk in self.r.iter_content(1024):
                if chunk:
                    f.write(chunk)


class Imitate:

    def isUrl(self, link):
        if re.match('(http[s]?:)?//[0-9a-zA-Z-_]+\..+', link, re.M | re.I) == None:
            return False
        else:
            return True

    def html(self):
        self.text = self.r.text.encode(self.r.encoding).decode(self.encoding)

    def rightDir(self, dir):
        if(re.match("\./.+", dir) != None):
            return dir
        else:
            return "./"+dir

    def __init__(self, url, root="./"):
        self.url = urlparse(url)
        self.oURL = url
        self.root = self.rightDir(root)
        if not os.path.exists(self.root):
            os.makedirs(self.root)
        self.text = ''
        self.doc = ''
        self.r = r.get(url)
        self.encoding = sys.getdefaultencoding()

    def detectDir(self, path):
        info = os.path.split(path)
        if not os.path.isdir(info[0]):
            os.makedirs(info[0])

    def dom(self):
        self.doc = bs(self.r.content, features="lxml")

    def ishtml(self):
        if not self.text:
            self.html()

    def getHtml(self):
        self.isDom()
        return self.doc.prettify()

    def output(self, path, content):
        self.detectDir(path)
        with open(path, "w", encoding=self.encoding) as f:
            f.write(content)

    def outHtml(self, path):
        self.isDom()
        self.output(path, self.doc.prettify())

    def isDom(self):
        if not self.doc:
            self.dom()

    def fixSrc(self, src):
        lists = src.split("/")
        words = []
        for i in lists:
            if i != '':
                words.append(i)
        return "/".join(words)

    def getContent(self, url):
        return r.get(url).content

    def baseUrl(self, url):
        down = Download()
        url = down.fixUrl(url)
        info = urlparse(url)[:3]
        path = '/'+'/'.join(info[2].split("/")[:-1])+"/"
        if path == '//':
            path = "/"
        return info[0]+"://"+info[1]+path

    def basePath(self, path):
        return self.root+"/" + os.path.split(self.fixPath(path))[0]

    def fixPath(self, path):
        info = os.path.split(path)
        path = []
        for i in info[0].split('/'):
            if i != '':
                path.append(i)
        path.append(info[1])
        return '/'.join(path)

    def clone_tag(self, tag):
        attrs = tag.attrs
        if attrs["src"]:
            if self.isUrl(attrs['src']):
                src = attrs["src"]
                info = urlparse(src)
                if self.doc.find(tag.name, tag.attrs).attrs['src']:
                    t = self.fixSrc(self.fixPath(info[1]+info[2]))
                    self.doc.find(tag.name, tag.attrs).attrs['src'] = t
                    print(t)
                source = self.root+"/" + info[1]+info[2]
            else:
                src = self.baseUrl(self.oURL)+"/"+attrs['src']
                if self.doc.find(tag.name, tag.attrs).attrs['src']:
                    t = self.fixSrc(self.fixPath(urlparse(src)[2]))
                    self.doc.find(tag.name, tag.attrs).attrs['src'] = t
                    print(t)
                source = self.root+"/"+urlparse(src)[2]
        elif attrs["href"]:
            if self.isUrl(attrs['href']):
                src = attrs["href"]
                info = urlparse(src)
                if self.doc.find(tag.name, tag.attrs).attrs['href']:
                    t = self.fixSrc(self.fixPath(info[1]+info[2]))
                    self.doc.find(tag.name, tag.attrs).attrs['href'] = t
                    print(t)
                source = self.root + "/" + info[1] + info[2]
            else:
                src = self.baseUrl(self.oURL)+"/"+attrs['href']
                if self.doc.find(tag.name, tag.attrs).attrs['href']:
                    t = self.fixSrc(self.fixPath(urlparse(src)[2]))
                    self.doc.find(tag.name, tag.attrs).attrs['href'] = t
                    print(t)
                source = self.root+"/"+urlparse(src)[2]
        down = Download()
        down.add(src, source)
        down.run()

    def run(self):
        self.isDom()
        for tag in self.doc.descendants:
            try:
                self.clone_tag(tag)
            except:
                pass
        if os.path.split(urlparse(self.oURL)[2])[1] == '':
            outpath = self.root+'/'+"index.html"
            self.output(outpath, self.doc.prettify())
        else:
            outpath = self.root+'/'+os.path.split(urlparse(self.oURL)[2])[1]
            self.output(outpath, self.doc.prettify())
